commit aa5d7d58ba40187bd8c6a2216bfd24514da78003
Author: Heikki Linnakangas <heikki.linnakangas@iki.fi>
Date:   Mon Mar 25 11:03:20 2013 +0200

    Add a server version check to pg_basebackup and pg_receivexlog.
    
    These programs don't work against 9.0 or earlier servers, so check that when
    the connection is made. That's better than a cryptic error message you got
    before.
    
    Also, these programs won't work with a 9.3 server, because the WAL streaming
    protocol was changed in a non-backwards-compatible way. As a general rule,
    we don't make any guarantee that an old client will work with a new server,
    so check that. However, allow a 9.1 client to connect to a 9.2 server, to
    avoid breaking environments that currently work; a 9.1 client happens to
    work with a 9.2 server, even though we didn't make any great effort to
    ensure that.
    
    This patch is for the 9.1 and 9.2 branches, I'll commit a similar patch to
    master later. Although this isn't a critical bug fix, it seems safe enough
    to back-patch. The error message you got when connecting to a 9.3devel
    server without this patch was cryptic enough to warrant backpatching.

diff --git a/src/bin/pg_basebackup/pg_basebackup.c b/src/bin/pg_basebackup/pg_basebackup.c
index 472df3a..d68e742 100644
--- a/src/bin/pg_basebackup/pg_basebackup.c
+++ b/src/bin/pg_basebackup/pg_basebackup.c
@@ -816,6 +816,9 @@ BaseBackup(void)
 	int			i;
 	char		xlogstart[64];
 	char		xlogend[64];
+	int			minServerMajor,
+				maxServerMajor;
+	int			serverMajor;
 
 	/*
 	 * Connect in replication mode to the server
@@ -823,6 +826,24 @@ BaseBackup(void)
 	conn = GetConnection();
 
 	/*
+	 * Check server version. BASE_BACKUP command was introduced in 9.1, so
+	 * we can't work with servers older than 9.1. We don't officially support
+	 * servers newer than the client, but the 9.1 version happens to work with
+	 * a 9.2 server. This version check was added to 9.1 branch in a minor
+	 * release, so allow connecting to a 9.2 server, to avoid breaking
+	 * environments that worked before this version check was added.
+	 */
+	minServerMajor = 901;
+	maxServerMajor = 902;
+	serverMajor = PQserverVersion(conn) / 100;
+	if (serverMajor < minServerMajor || serverMajor > maxServerMajor)
+	{
+		fprintf(stderr, _("%s: unsupported server version %s\n"),
+				progname, PQparameterStatus(conn, "server_version"));
+		disconnect_and_exit(1);
+	}
+
+	/*
 	 * Start the actual backup
 	 */
 	PQescapeStringConn(conn, escaped_label, label, sizeof(escaped_label), &i);
